@@ -48,7 +48,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
     """
     ####################################################################################
     ####                              Auto Time Series                              ####
-    ####                               Version 0.1.1                                ####
+    ####                               Version 0.1.4                                ####
     ####                    Conceived and Developed by Kevin Chen                   ####
     ####                       Original Credit to Ram Seshadri                      ####
     ####                            All Rights Reserved                             ####
@@ -345,8 +345,8 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
 
 
     ########################### This is where we store all models in a nested dictionary ##########
-    mldict = lambda: defaultdict(mldict)
-    ml_dict = mldict()
+    modeldict = lambda: defaultdict(modeldict)
+    model_dict = modeldict()
     try:
         if model_type.lower() == 'all':
             print('Running all model types. This will take a long time. Be Patient...')
@@ -393,8 +393,8 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
         model, forecast_df, rmse, norm_rmse = build_prophet_model(
                                     ts_df, ts_column, target, forecast_period,
                                     score_type, verbose, conf_int)
-        ml_dict[name]['model'] = model
-        ml_dict[name]['forecast'] = forecast_df['yhat'].values
+        model_dict[name]['model'] = model
+        model_dict[name]['forecast'] = forecast_df['yhat'].values
         ##### Make sure that RMSE works, if not set it to np.inf  #########
         if score_type == 'rmse':
             score_val = rmse
@@ -403,14 +403,14 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
         # except:
         #     print('    FB Prophet may not be installed or Model is not running...')
         #     score_val = np.inf
-        ml_dict[name][score_type] = score_val
+        model_dict[name][score_type] = score_val
     if model_type.lower() in ['stats', 'all']:
         ##### First let's try the following models in sequence #########################################
         # nsims = 100   ### this is needed only for M-H models in PyFlux
         # name = 'PyFlux'
         # print(colorful.BOLD + '\nRunning PyFlux Model...' + colorful.END)
         # try:
-        #     ml_dict[name]['model'], ml_dict[name]['forecast'], rmse, norm_rmse = \
+        #     model_dict[name]['model'], model_dict[name]['forecast'], rmse, norm_rmse = \
         #         build_pyflux_model(ts_df, target, p_max, q_max, d_max, forecast_period,
         #                            'MLE', nsims, score_type, verbose)
         #     if isinstance(rmse, str):
@@ -428,12 +428,12 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
         #     score_val = rmse
         # else:
         #     score_val = norm_rmse
-        # ml_dict[name][score_type] = score_val
+        # model_dict[name][score_type] = score_val
         ################### Let's build an ARIMA Model and add results #################
         name = 'ARIMA'
         print(colorful.BOLD + '\nRunning Non Seasonal ARIMA Model...' + colorful.END)
         try:
-            ml_dict[name]['model'], ml_dict[name]['forecast'], rmse, norm_rmse = build_arima_model(ts_df[target],
+            model_dict[name]['model'], model_dict[name]['forecast'], rmse, norm_rmse = build_arima_model(ts_df[target],
                                                     stats_scoring,p_max,d_max,q_max,
                                     forecast_period=forecast_period,method='mle',verbose=verbose)
         except:
@@ -443,12 +443,12 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
             score_val = rmse
         else:
             score_val = norm_rmse
-        ml_dict[name][score_type] = score_val
+        model_dict[name][score_type] = score_val
         ############# Let's build a SARIMAX Model and get results ########################
         name = 'SARIMAX'
         print(colorful.BOLD + '\nRunning Seasonal SARIMAX Model...' + colorful.END)
         # try:
-        ml_dict[name]['model'], ml_dict[name]['forecast'], rmse, norm_rmse = build_sarimax_model(ts_df[target], stats_scoring, seasonality,
+        model_dict[name]['model'], model_dict[name]['forecast'], rmse, norm_rmse = build_sarimax_model(ts_df[target], stats_scoring, seasonality,
                                                 seasonal_period, p_max, d_max, q_max,
                                                 forecast_period,verbose)
         # except:
@@ -458,7 +458,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
             score_val = rmse
         else:
             score_val = norm_rmse
-        ml_dict[name][score_type] = score_val
+        model_dict[name][score_type] = score_val
         ########### Let's build a VAR Model - but first we have to shift the predictor vars ####
         name = 'VAR'
         if len(preds) == 0 or univarate:
@@ -474,7 +474,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
                                             %len(preds))
                     ts_df[preds] = ts_df[preds].shift(1)
                     ts_df.dropna(axis=0,inplace=True)
-                    ml_dict[name]['model'], ml_dict[name]['forecast'], rmse, norm_rmse = build_var_model(ts_df[[target]+preds],stats_scoring,
+                    model_dict[name]['model'], model_dict[name]['forecast'], rmse, norm_rmse = build_var_model(ts_df[[target]+preds],stats_scoring,
                                                 forecast_period, p_max, q_max)
                 else:
                     print(colorful.BOLD + '\nNo predictors available. Skipping VAR model...' + colorful.END)
@@ -489,7 +489,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
         else:
             score_val = norm_rmse
         ########################################################################
-        ml_dict[name][score_type] = score_val
+        model_dict[name][score_type] = score_val
 
 
     ##################################################################################################
@@ -604,10 +604,10 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
                     best = run_ensemble_model(train[preds], train[target], 'TimeSeries',
                                               score_type, verbose)
                     bestmodel = best[0]
-                    ml_dict[name]['model'] = bestmodel
+                    model_dict[name]['model'] = bestmodel
                     ### Certain models dont have random state => so dont do this for all since it will error
                     #best.set_params(random_state=0)
-                    ml_dict[name]['forecast'] = bestmodel.fit(train[preds],train[target]).predict(test[preds])
+                    model_dict[name]['forecast'] = bestmodel.fit(train[preds],train[target]).predict(test[preds])
                     rmse, norm_rmse = print_dynamic_rmse(test[target].values,
                                                 bestmodel.predict(test[preds]),
                                                 train[target].values)
@@ -634,23 +634,23 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
             rmse = np.inf
             norm_rmse = np.inf
         ########################################################################
-        ml_dict[name][score_type] = score_val
+        model_dict[name][score_type] = score_val
 
     print("\n\n-------------------------------------------------------------------")
     print("STEP 10) Model Search IV (DL Models)")
     print("-------------------------------------------------------------------\n")
 
-    if model_type.lower() in ['dl', 'deep', 'prophet', 'all']:
+    if model_type.lower() in ['dl', 'dnn', 'deep', 'all']:
 
-        if tf.test.is_gpu_available():
+        if len(tf.config.list_physical_devices('GPU')) > 0:
             print("GPU is enabled.")
         else:
             print("Running on CPU as GPU is not enabled.")
 
-        dl_dict = run_deep_model(X_train, y_train, X_val, y_val, n_input, n_output,
-                                 n_units, d_rate, n_epoch, n_batch, score_type)
-        ipdb.set_trace()
-        pass
+        model_dict = run_deep_model(model_dict, X_train, y_train, X_val, y_val,
+                                 n_input, n_output, n_units, d_rate, n_epoch,
+                                 n_batch, score_type)
+
 
     print("\n\n-------------------------------------------------------------------")
     print("STEP 11) Model Results Output")
@@ -658,16 +658,16 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
 
     ######## Selecting the best model based on the lowest rmse score ######
     f1_stats = {}
-    for key, val in ml_dict.items():
-        f1_stats[key] = ml_dict[key][score_type]
+    for key, val in model_dict.items():
+        f1_stats[key] = model_dict[key][score_type]
     best_model_name = min(f1_stats.items(), key=operator.itemgetter(1))[0]
     print(colorful.BOLD + '\nBest Model is:' + colorful.END)
     print('    %s' % best_model_name)
-    best_model = ml_dict[best_model_name]['model']
-    #print('    Best Model Forecasts: %s' %ml_dict[best_model_name]['forecast'])
-    print('    Best Model Score: %0.2f' % ml_dict[best_model_name][score_type])
+    best_model = model_dict[best_model_name]['model']
+    #print('    Best Model Forecasts: %s' %model_dict[best_model_name]['forecast'])
+    print('    Best Model Score: %0.2f' % model_dict[best_model_name][score_type])
 
-    return ml_dict, data_dict
+    return model_dict, data_dict
 
 
 ##########################################################
